import os
import arcpy
import threading
import time
import sys
import csv
import migration_utils as utils

#-----------------------------------------------------------------------------------------------------
# Settings
#-----------------------------------------------------------------------------------------------------

pro_nis_schema_xml = r'C:\ArcGIS\Resources\Maritime\NAUTICAL_ENC_TEMPLATE_GX_EXTCLSID.xml'
working_dir = r'C:\M\data\migrate\temp'

if (not os.path.exists(working_dir)):
    print('working directory: {} does not exists\n'.format(working_dir))

# import temp pro nis schema from xml
pro_nis_schema = os.path.join(working_dir, 'pro_nis_schema.gdb')

if(arcpy.Exists(pro_nis_schema)):
    arcpy.Delete_management(pro_nis_schema)

utils.StartProgressor("\t\t Creating temp NIS gdb")
arcpy.CreateFileGDB_management(working_dir, "pro_nis_schema.gdb", "CURRENT")
utils.StopProgressor()
utils.StartProgressor("\t\t Importing NIS schema to the temp gdb")
arcpy.ImportXMLWorkspaceDocument_management(pro_nis_schema, pro_nis_schema_xml, "DATA", '')
utils.StopProgressor()

arcpy.env.workspace = pro_nis_schema
feature_classes = arcpy.ListFeatureClasses(feature_dataset='Nautical') 

fc_to_attr_rule_file = {}
# export attr rules
print("\t\t Exporting attribute rules from pro schema")
for fc in feature_classes:
    desc = arcpy.Describe(fc)
    baseName = desc.baseName
    unqualifiedName = baseName.split('.')[-1]
    csv_file_path = os.path.join(working_dir, unqualifiedName + ".csv")
    if arcpy.Exists(csv_file_path):
        arcpy.Delete_management(csv_file_path)
    fc_full_path = os.path.join(pro_nis_schema, 'Nautical', fc)
    arcpy.ExportAttributeRules_management(fc_full_path, csv_file_path)
    fc_to_attr_rule_file[fc_full_path] = csv_file_path
    print("\t\t\t{}".format(fc))

# delete the attribute rules from the schema
# print("\t\t Deleting attribute rules from pro schema")
# for fc in fc_to_attr_rule_file.keys():
#     csv_file_path = fc_to_attr_rule_file[fc]
#     rule_names = []
#     with open(csv_file_path, encoding="utf-8-sig") as csv_file:
#         csv_reader = csv.DictReader(csv_file, dialect='excel')
#         for row in csv_reader:
#             rule_names.append(row['NAME'])
#     if (len(rule_names) > 0):
#         arcpy.management.DeleteAttributeRule(fc, ';'.join(rule_names))
#         print("\t\t\t{}".format(fc))