
# -*- coding: utf-8 -*-

#
#   Checklist
# - Create a backup of NIS
# - If the NIS is SDE database, NIS components should be versioned as documented in
#   http://desktop.arcgis.com/en/arcmap/10.3/guide-books/extensions/maritime-charting/registering-nis-components-as-versioned-and-enable-archiving.htm
#  
# Troubleshooting:
# - Make sure comtypes module is installed. Run the command (python -m pip install comtypes) from the above console environment
# - If fails due to insufficient privilege, run as administrator
#

#-----------------------------------------------------------------------------------------------------
# Settings
#-----------------------------------------------------------------------------------------------------

# 1. Temporary path to create the pro NIS schema
working_dir = r'C:\M\data\migrate\temp'

# 2. Product Library
pl = r'C:\M\data\migrate\2series\PRODUCT_LIBRARY.gdb'

# examples
# pl = r'C:\temp\fgdbs\AML\NAUTICAL_AML_PRODUCT_LIBRARY_10.5.gdb'
# pl = r'C:\temp\fgdbs\micklefirthPL.gdb'

# 3. Classes/Series to migrate and corresponding NIS paths
# (Class names are unique across different solutions in the Product Library.)
# Migrates only the specified classes.
# Migrate only the specified series.
# If only class name is specified, all the series inside it are migrated. 
# All the series will inherit the NIS from the parent class.
# If a series has a different NIS setting than the class, add an entry as Class/Series pointing to its NIS.
# This setting is a python dictionary, so in case of duplicate keys, the last one overrides previous ones.

nis_paths = {
    'ENC/District A': r'C:\M\data\migrate\2series\NIS.gdb',
    'ENC/bENC': r'C:\M\data\migrate\2series\NIS.gdb',
}

# examples

# Migrate the all the series in the ENC class
# nis_paths = {
#     'ENC': r'C:\M\temp\fgdbs\micklefirthNIS.gdb',
# }

# Migrate the two series in the ENC class.
# nis_paths = {
#     'ENC/CGD05': r"C:\M\test\migration\nsbisdb4_pacific2_nis@nis.sde",
#     'ENC/卡说刷啊': r"C:\M\test\migration\nsbisdb4_pacific2_nis@nis.sde"
# }

# AML classes pointing to the corresponding NIS 
# nis_paths = {
    # 'CLB': r'C:\M\temp\CLB.gdb',
    # 'ESB': r'C:\M\temp\ESB.gdb',
    # 'LBO': r'C:\M\temp\LBO.gdb',
    # 'MFF': r'C:\M\temp\fgdbs\AML\MFF.gdb',
    # 'RAL': r'C:\M\temp\RAL.gdb',
    # 'SBO': r'C:\M\temp\SBO.gdb',
# }

# 4. Set installation root directories, or leave it empty to let the script try to auto-detect.
arcmap_root = ''
production_mapping_root = ''

# example
# arcmap_root = r'C:\Program Files (x86)\ArcGIS\Desktop10.7'
# production_mapping_root = r'C:\Program Files (x86)\ArcGIS\EsriProductionMapping\Desktop10.7'

# 5. Set the chunkSize.
# Updating the NOIDs in oracle database may fail for feature classes with large number of rows and if the 
# the UNDO tablespace size is not sufficient to accomodate the transaction size. Set low number for low UNDO tablespace.
chunkSize = 100000

# 6. Set Agency and FIDS
agency = '4E' #ESRI
fids = '12345'

# 7. logging verbosity
verbose = True

#-----------------------------------------------------------------------------------------------------
# End Settings
#-----------------------------------------------------------------------------------------------------

from migrate_impl import Migrate
Migrate(arcmap_root, production_mapping_root, pl, nis_paths, working_dir, chunkSize, agency, fids, verbose)
